
/*   Emetteur Récepteur UHF avec module DRA818 V
 *      ----------------------------------------
 *   couvre de 430 à 440 MHz
 *   - Au pas 25 et 12.5 Khz
 *   - Décalage - 9600 KHz pour accéder aux relais. *
 *   - Avec ou sans squelch. Ici réglé 1 ou 0.
 *  Voir programme pour réglage du squelch (de 0 à _8)
 *
 *  Bouton "Pas" connecté à Pin 4. Résistance de tirage au +
 *  Bouton "Offset -9600" connecté à Pin 5. Résistance de tirage au +
 *  Bouton "Squelch" connecté à Pin 6. Résistance de tirage au +
 *
 *  Plus d'information sur mon site http://f5mna.free.fr.
 *
 *  Version 2 10/2017
 */


//Afficheur
#include <Adafruit_ssd1306syp.h>
#define SDA_PIN 8
#define SCL_PIN 9
Adafruit_ssd1306syp display(SDA_PIN, SCL_PIN);
//Encodeur rotatif
volatile boolean modif;
volatile boolean up;
#define PINA 2
#define PINB 3
#define INTERRUPT 0            // interrupt 0: pin 2, interrupt 1: pin 3

//Appel 1750 Hz
#define Appel_pin 12    // Appel
#define pinBF 7         // 1750 Hz


//Frequences, Pas, offset -600
float frx, ftx, Pas, Step, Offset, Decal;
const int Pas_Pin = 4;         // Bouton "Pas" connecté à Pin 4
// Résistance de tirage au +
const int Decal_Pin = 5;       // Bouton "Offset -600" connecté à Pin 5
// Résistance de tirage au +
const int Squelch_Pin = 6;     // Bouton "Squelch" connecté à Pin 6
// Résistance de tirage au +

int n, val0, val1, val2, val3;

// paramètres réglés pour DRA818V
String bw = "1";               // Pas en KHz ( 0 = 12.5 or 1 = 25 )
String tx_ctcss = "0000";      // fréquence de ctcss (0000 - 0038); 0000 = "no CTCSS"
String rx_ctcss = "0000";      // fréquence de ctcss (0000 - 0038); 0000 = "no CTCSS"

///////////////////   Réglage du squelch     /////////////////////////////
String squ = "1";              // niveau du silencieux (0-8); 0 = ouvert"
String squelch = "1";



void setup() {
  Serial.begin (9600);
  
  pinMode (Pas_Pin, INPUT);
  pinMode (Decal_Pin, INPUT);
  pinMode (Squelch_Pin, INPUT);
  
  //Encodeur rotatif
  digitalWrite (PINA, HIGH);
  digitalWrite (PINB, HIGH);
  attachInterrupt (INTERRUPT, Int, CHANGE);   // interrupt 0: pin 2, interrupt 1: pin 3
  n = 0;
  frx = 435000;               //Frequence rx en KHz à la mise en route (Choisir votre QRG favorite)
  Decal = 0;
   //-------------- Affichage lors de l'initialisation  -------------
  display.initialize();
  display.setTextSize(2);
  display.setTextColor(WHITE);
  display.setCursor(20, 29); // H, V
  //display.println("VFO-DDS");
  display.println("DRA818 U");
  display.setTextSize(1);
  display.setCursor(90, 55); // H, V
  display.println("F5MNA");
  display.update();
  delay(2000);
  display.clear();
  display.setTextSize(2);
  display.setTextColor(WHITE);
  display.setCursor(20, 29); // H, V
  display.println("435.0000");// Première fréquence affichée selon choix
  display.update();


  Serial.println ("AT+DMOCONNECT"); // Se connecter au module
  Serial.println("");
  Serial.println ("");
  delay (100);
  //Envoi Data au DRA818
  Serial.print ("AT+DMOSETGROUP="); // Commencer un message
  Serial.print (bw);
  Serial.print (",");
  Serial.print (frx / 1000, 4);
  Serial.print (",");
  Serial.print (frx / 1000, 4);
  Serial.print (",");
  Serial.print (tx_ctcss);
  Serial.print (",");
  Serial.print (squ);
  Serial.print (",");
  Serial.println (rx_ctcss);
}

void loop() {

  
   ///////////////// Appel 1750 Hz ////////////
   val3 = digitalRead(Appel_pin);  
   Serial.println (val3);
   if (val3 == LOW){
    tone(pinBF, 1750, 500);
   }
  ////////////////// PAS  (Step) //////////////////////
  val0 = digitalRead(Pas_Pin);   // Lecture bouton "Pas"
  digitalWrite(Pas_Pin, val0);
  if (val0 == HIGH)
  { Pas = 25;
    bw = "1";
  }
  else
  { Pas = 12.5;
    bw = "0";
  }
  
  ////////////////// DECALAGE  (Offset) ////////////////
  val1 = digitalRead(Decal_Pin);  // Lecture bouton "Offset - 600 KHz"
  digitalWrite(Decal_Pin, val1);
  if (val1 == HIGH)
  {
    Decal = 0;
  }
  else
  {
    if (frx >= 439600) (Decal = 9600);}
 
  ////////////////// Squelch) ////////////////
  val2 = digitalRead(Squelch_Pin);
  digitalWrite(Squelch_Pin, val2);
  if (val2 == HIGH)
  {
    squ = "1";
  }
  else
  {
    squ = "0";
  }

  if ((squelch != squ) || (Offset != Decal) || (Step != Pas)) {   // Si modification de la valeur du squelch de l'offset ou du pas ....
    display.clear();
    display.setTextSize(2);
    display.setTextColor(WHITE);
    display.setCursor(20, 29); // H, V
    display.println((frx / 1000), 4);
    if (Decal == 9600) {
    display.setTextSize(1);
    display.setCursor(90, 55); // H, V
    display.println("Offset");}
    else
    {display.setTextSize(1);
    display.setCursor(90, 55); // H,V
    display.println("      ");}
    display.update();

    Serial.println ("AT+DMOCONNECT"); //Se connecter au module
    Serial.println("");
    Serial.println ("");
    delay (200);
    //Envoi Data au DRA818
    Serial.print ("AT+DMOSETGROUP="); // commencer un message
    Serial.print (bw);
    Serial.print (",");
    Serial.print ((frx - Decal)/ 1000, 4);
    Serial.print (",");
    Serial.print (frx / 1000, 4);
    Serial.print (",");
    Serial.print (tx_ctcss);
    Serial.print (",");
    Serial.print (squ);
    Serial.print (",");
    Serial.println (rx_ctcss);  
  }


  if (modif) //si rotation de l'encodeur....
  {
    display.clear();
    if (up) frx = (frx + Pas);
    else    frx = (frx - Pas);
    modif = false;
  
    if (frx < 430000) frx = 430000; // Limite de bande
    if (frx > 440000) frx = 440000; // Limite de bande

    display.setTextSize(2);
    display.setTextColor(WHITE);
    display.setCursor(20, 29); // H, V
    display.println((frx / 1000), 4);
    
    if (Decal == 9600) {
    display.setTextSize(1);
    display.setCursor(90, 55); // H, V
    display.println("Offset");}
    else
    { display.setTextSize(1);
    display.setCursor(90, 55); // H, V
    display.println("     ");}   
     
    display.update();

    Serial.println ("AT+DMOCONNECT"); //Se connecter au module
    Serial.println("");
    Serial.println ("");
    delay (200);
    //Envoi Data au DRA818
    Serial.print ("AT+DMOSETGROUP="); // commencer un message
    Serial.print (bw);
    Serial.print (",");
    Serial.print ((frx - Decal)/ 1000, 4);
    Serial.print (",");
    Serial.print (frx / 1000, 4);
    Serial.print (",");
    Serial.print (tx_ctcss);
    Serial.print (",");
    Serial.print (squ);
    Serial.print (",");
    Serial.println (rx_ctcss);
  }
  squelch = squ;
  Offset = Decal;
  Step = Pas;
  
}

// Routine Interrupt
void Int()
{
  if (digitalRead (PINA)) {
    n++;
    if (n == 2) {
      up = digitalRead (PINB);
    }
    else
    { up = !digitalRead (PINB);
      n = 0;
      modif = true;
    }
  }
}

